
----

## Business model and data

* A business model “describes the rationale of how an organization creates, delivers, and captures value.” A Data Business Model is a business model where data is an indispensable component.

---

## How can Data be Monetized?

* Data itself 
* Data storage
* Data transfer
* Data filtering
* Data aggregation
* Data analysis
* Generated data

----

  * If you have a valuable dataset that others would pay to access, then you can sell it directly (e.g. Factual, FullContact, Yodlee) or build the only access point and sell it indirectly (e.g. DataFox, Mattermark, Bloomberg, and LoopNet).
Data helps drive revenue, and built products based on data. As you learn about customer preferences, you can improve product recommendations and greatly increase each customer’s lifetime value. This is huge for Amazon and most eCommerce companies. If you’re building a repository of content (which is a form of data), you can use that to drive ads. You can also use data about your users to better monetize ad targeting, like Facebook and Twitter do.
Data helps improve profit margins. Possible ways to improve margins with data include conversion funnel optimization, price optimization, and accurate supply/demand prediction. Examples: Amazon, online marketplaces, and every company that uses A/B testing.
Specific Monetization Game Plans
How can you turn the business models above into actual businesses? Here are some specific recipes for different types of products:

----

## Content Companies

Build a content site, use engagement data to decide what content to produce (e.g. BuzzFeed, Bleacher Report)
Build a user-generated content site, display relevant ads/affiliate links/product recs next to content (e.g. Yelp, Pinterest, eventually Quora)
Use behavioral data to create better content recommendations and higher engagement, then charge for usage (e.g. Pandora, Netflix)

eCommerce

Use purchase and conversion data to implement profit-maximizing pricing (e.g. Amazon, eBay, most eCommerce companies)
Use data to create better product recommendations and increase basket size (e.g. Warby Parker, Lumoid, True&Co)
(These two recipes can also be applied to other companies, like SaaS startups, but they have a deeper impact on eCommerce companies because of the lower margins. Taking a SaaS company from a 50% margin to a 75% margin is great, but taking an eCommerce company from -5% margin to ￼20% margin is what turns it into a real business.)

----

## Data providers

Sell access to premium data (LinkedIn subscriptions, IMDB Pro, DataFox, LoopNet).
Sell API access to raw data (Factual, Clearbit, Yodlee)
Help customers augment their datasets with external data (e.g. Factual for location data, Zephyr Health for medical and health data, Socrata for government data). This is different than selling data because that model is more about selling an entire self-contained datasets to customers; this model is more about helping customers who already have some data enrich their data with other attributes. This business model is often much more reliant on integration and deduping algorithms than on data acquisition.

## B2B and B2C tools

Build models from product usage data (e.g. LendUp for credit scoring, Sift Science for fraud detection, Framed Data for churn prediction, Metromile for car insurance). Increased product usage leads to better models, which are both more valuable to customers and more difficult for competitors to replicate.
Build a consumer app that saves time for customers and collects data as a result (e.g. inbox organization tools like Unroll.Me, shopping related tools like Honey and Two Tap, and smart launchers and homescreens like Bento). This data can be used for better recommendations or ad targeting, and can often be monetized by affiliate fees.
Build a SaaS product that makes some industry more efficient, usually through replacing faxes/voicemails/emails with online forms. Use form data to build killer features (e.g. Flexport, SimpleLegal, Sourcery)

----

## Cases study

---

## Cases study

### Zoho

Having established itself as a SaaS leader in office productivity and CRM tools, Zoho offers a versatile data analytics platform geared for both professional data scientists and mid-level staffers who want a self-service option. The application has an intuitive drag and drop interface as well as a classic spreadsheet-style interface. Zoho Analytics is geared for organizations that want to provide actionable data analytics insight to staffers at every level.

----

## Cases study

### Salesforce

Salesforce, the king of SaaS, became a software vendor when it announced plans to purchase Tableau Systems, a data visualization firm that has expanded from its original mission to include Big Data research. It offers visualization of data from any source, from Hadoop to Excel files. Salesforce has its own Big Data tools in joined reports, which lets customers compare different data sets in the hopes of getting insights from customer data.

----

## Cases study

### IBM

IBM supports Big Data analytics through a number of databases, including DB2, Informix, and InfoSphere. It also has popular analytics applications such as Cognos and SPSS. In terms of pure Big Data, IBM has its own Hadoop distribution, Stream Computing to perform real-time data processing, IBM BigInsights for Apache Hadoop, and IBM BigInsights on Cloud offering Hadoop as a service through IBM Cloud.

----

## Cases study

### HP Enterprise

HP Enterprise’s main Big Data product is Vertica Analytics Platform, designed to manage a large volume of structured data with fast query performance on Hadoop and SQL Analytics. It also has Vertica Advanced Analytics for deployment across multiple clouds, commodity hardware, and on any Hadoop distribution system. HPE also has HAVEn, a Big Data platform available on demand focused on machine learning.

HPE has a number of hardware products, including HPE Moonshot, the ultra-converged workload servers, the HPE Apollo 4000 purpose-built server for Big Data, analytics and object storage. HPE ConvergedSystem is designed for SAP HANA workloads and HPE 3PAR StoreServ 20000 stores analyzed data, addressing existing workload demands and future growth.

----

## Cases study

### SAP

SAP's main Big Data tool is its HANA in-memory relational database that works with Hadoop. HANA is a traditional row-and-column database, but it can perform advanced analytics, like predictive analytics, spatial data processing, text analytics, text search, streaming analytics, and graph data processing and has ETL (Extract, Transform, and Load) capabilities. SAP also offers data warehousing to manage all of your data from a single platform, cloud services, as well as data management tools for governance, orchestration, cleansing, and storage.

----

## Cases study

### Oracle

Oracle has a dedicated Big Data Appliance server preloaded and configured with a number of Oracle software products. This includes Oracle Autonomous Data Warehouse, Oracle NoSQL Database, Apache Hadoop, Oracle Data Integrator with Application Adapter for Hadoop, and Oracle Loader for Hadoop. It also has a number of on-premises and cloud-based analytics products as well as integration platforms and streaming analytics to handle data as it comes in.

Apache
The Apache Hadoop software library remains the framework for Big Data although many vendors have taken the framework and built their own proprietary and unique functions on it. The base system provides an outline to do your own customization and is designed to scale up from a single server to thousands. Apache also offers Spark, which does in-memory, real-time processing. Apache ￼also offers Storm, a real-time, fault-tolerant processing system designed to run parallel calculations that run across a cluster of machines.

Microsoft
Microsoft's Big Data strategy – helped by its Azure cloud platform – is fairly broad and has grown fast. It has a partnership with Hortonworks and offers the HDInsights tool based for analyzing structured and unstructured data on Hortonworks Data Platform. Microsoft also offers the iTrend platform for dynamic reporting of campaigns, brands and individual products.
SQL Server 2016 comes with a connector to Hadoop for Big Data processing, and Microsoft recently acquired Revolution Analytics, which made the only Big Data analytics platform written in R, a programming language for building Big Data apps without requiring the skills of a data scientist.

Amazon Web Services
Amazon Web Services offers an array of Big Data products, the main one being the Hadoop-based Elastic MapReduce (EMR), plus Athena for basic database analytics, Kinesis and Storm for real-time analytics, and a number of databases, including DynamoDB Big Data database, Redshift, and NoSQL.
Naturally, AWS benefits greatly in the data market from its overwhelming cloud presence. Many clients turn to their existing cloud provider to purchase Big Data services, which create an enormous natural funnel for AWS.

Google
Google continues to expand on its Big Data analytics offerings, starting with BigQuery, a cloud-based analytics platform for quickly analyzing very large datasets. BigQuery is serverless, so there is no infrastructure to manage and you don't need a database administrator, it uses a pay-as-you-go model.
Google also offers Dataflow, a real time data processing service, Dataproc, a Hadoop/Spark-based service, Pub/Sub to connect your services to Google messaging, and Genomics, which is focused on genomic sciences.

Cloudera
Cloudera recently merged with Hortonworks, in a marriage of the two largest Hadoop providers. While both focused on the Hadoop market they took different approaches. Hortonworks targeted more technical users and took a pure open source approach, while Cloudera went for the IT market and offered some proprietary tools. Combined, the firm says it will offer a broad spectrum of Hadoop products.

----

## Références

For more content about business model: 

https://www.feedough.com/what-is-a-business-model/

